# Step 1
library(biomod2)
library(raster)
library(dismo)
library(sp)
library(sdmpredictors)
library(rgbif)
library(ade4)

#Step 2
spp_Aspara<-name_suggest(q='Asparagopsis armata',rank = 'species',limit = 10000)
Armata_data_Ire<-occ_search(taxonKey = 5279840, country = 'IE', fields=c('name','key','country','decimalLatitude','decimalLongitude'),hasCoordinate = T,limit=1000,return = 'data')
View(Armata_data_Ire)
Armata_data_Ire[["data"]]
Armata_Ire<-(Armata_data_Ire[["data"]])
View(Armata_Ire)
write.csv(Armata_Ire,"~A.armata_Ireland.csv")
Armata_data_Ire<-read.csv("~A.armata_Ireland.csv", header=T)

spp_Aspara<-name_suggest(q='Asparagopsis armata',rank = 'species',limit = 10000)
Armata_data_NZ<-occ_search(taxonKey = 5279840, country = 'NZ', fields=c('name','key','country','decimalLatitude','decimalLongitude'),hasCoordinate = T,limit=1000,return = 'data')
View(Armata_data_NZ)
Armata_data_NZ[["data"]]
Armata_NZ<-(Armata_data_NZ[["data"]])
View(Armata_NZ)
write.csv(Armata_NZ,"~A.armata_NZ.csv")
Armata_data_NZ<-read.csv("~A.armata_NZ.csv", header=T)

#Step 3
Environment<-load_layers(c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m","MS_biogeo05_dist_shore_5m","MS_bathy_5m"))
# Environmental layers with Ulva layer provided in SI. Layers are downloaded through sdmpredictors
#Envi_Ire_sub<-stack(subset(Environment,c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m","MS_biogeo05_dist_shore_5m","MS_bathy_5m")))


# Step 4 Country Shapefile
Ireland<-shapefile('~/eez-2Ireland/eez.shp')
# Ireland eez shapefile provided in marineregions.org
Envi_Ire<-mask(Environment, Ireland)
Envi_Ire<-crop(Environment,Ireland)
New_Zealand<-shapefile('~NZ_mainland_23aug04_oai.shp')
# New Zealand eez shapefile provided in marineregions.org
Envi_NZ<-mask(Environment,New_Zealand)
Envi_NZ<-crop(Environment,New_Zealand)

Envi_Ire_sub<-stack(subset(Envi_Ire,c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m","MS_biogeo05_dist_shore_5m","MS_bathy_5m")))
Envi_NZ_sub<-stack(subset(Envi_NZ,c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m","MS_biogeo05_dist_shore_5m","MS_bathy_5m")))

#Step 5 Data formatting 
resp.name<-"Asparagopsis armata"
Aarmata_data_Ireland<-BIOMOD_FormatingData(resp.var = rep(1,nrow(Armata_Ire)),expl.var = Envi_Ire_sub,resp.xy = Armata_Ire[,c('decimalLongitude','decimalLatitude')],resp.name=resp.name,PA.nb.rep=1,PA.nb.absences=5000,PA.strategy='random')
Aarmata_data_Ireland
Armata_Ire_coord<-Aarmata_data_Ireland@coord
View(Armata_Ire_coord)
write.csv(Armata_Ire_coord,file = "~A.armata_Ireland_coord_presence_absence.csv")
Armata_data_Ire_coord<-read.csv("~A.armata_Ireland_coord_presence_absence.csv", header=T)
A<-c()
P<-c()
totalCount<-nrow(Armata_data_Ire_coord)-nrow(Armata_Ire)
for(i in 1:totalCount){A<-c(A,0)}
for(i in 1:nrow(Armata_Ire)){P<-c(P,1)}
PA<-c(P,A)
Armata_data_Ire_presence_absences<-cbind(Armata_data_Ire_coord, PA)
write.csv(Armata_data_Ire_presence_absences, file="~A.armata_Ireland_presence_absence.csv")
Armata_data_Ire_presence_absences<-read.csv("~A.armata_Ireland_presence_absence.csv", header=T)

# Armata_data_Ire_coord and Armata_data_Ire_presence_absences to be combined to create occurence and 5000 pseudo absences for A.armata in Ireland

resp.name<-"Asparagopsis armata"
Aarmata_data_NZ<-BIOMOD_FormatingData(resp.var = rep(1,nrow(Armata_NZ)),expl.var = Envi_NZ_sub,resp.xy = Armata_NZ[,c('decimalLongitude','decimalLatitude')],resp.name=resp.name,PA.nb.rep=1,PA.nb.absences=5000,PA.strategy='random')
Aarmata_data_NZ
Armata_NZ_coord<-Aarmata_data_NZ@coord
View(Armata_NZ_coord)
write.csv(Armata_NZ_coord,file = "~A.armata_NZ_coord_presence_absence.csv")
Armata_data_NZ_coord<-read.csv("~A.armata_NZ_coord_presence_absence.csv", header=T)
A<-c()
P<-c()
totalCount<-nrow(Armata_data_NZ_coord)-nrow(Armata_NZ)
for(i in 1:totalCount){A<-c(A,0)}
for(i in 1:nrow(Armata_NZ)){P<-c(P,1)}
PA<-c(P,A)
Armata_data_NZ_presence_absences<-cbind(Armata_data_NZ_coord, PA)
write.csv(Armata_data_NZ_presence_absences, file="~A.armata_NZ_presence_absence.csv")
Armata_data_NZ_presence_absences<-read.csv("~A.armata_NZ_presence_absence.csv", header=T)

NZPA<-as.data.frame(Armata_data_Ire_presence_absences)
IEPA<-as.data.frame(Armata_data_NZ_presence_absences)
CombinedPA<-rbind(NZPA, IEPA)

write.csv(CombinedPA, "~CombinedPA.csv")

# This is to be repeated three times to create three different data sets


