# Step 1
library(biomod2)
library(raster)
library(dismo)
library(sp)
library(sdmpredictors)
library(rgbif)
library(ade4)

# Step 2 Species Data
setwd()
#Read in one of the three combinedPA data.frames you created in Part 1
DataSpecies1<-read.csv("~CombinedPA1.csv")
DataSpecies1

# Step 3 
Environment<-load_layers(c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m"))
Envi_Ire_sub<-stack(subset(Environment,c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m")))

# Step 4 Data formatting
myRespXY <- DataSpecies1[,c("decimalLongitude","decimalLatitude")]
myRespName<-"PA"
myResp <- as.numeric(DataSpecies1[,myRespName])
myBiomodData <- BIOMOD_FormatingData(resp.var = myResp,expl.var = Environment, resp.xy = myRespXY, resp.name = myRespName)
myBiomodData

# Step 5 Country Shapefile
Ireland<-shapefile('~eez-2Ireland/eez.shp')
# Ireland eez shapefile provided in marineregions.org
Envi_Ire<-mask(Environment, Ireland)
Envi_Ire<-crop(Environment,Ireland)
New_Zealand<-shapefile('~NZ_mainland_23aug04_oai.shp')
# New Zealand eez shapefile provided in marineregions.org
Envi_NZ<-mask(Environment,New_Zealand)
Envi_NZ<-crop(Environment,New_Zealand)

# Step 6 Modeling
Aarmata_opt<-BIOMOD_ModelingOptions()
Aarmata_models_NZ_Ire<-BIOMOD_Modeling(myBiomodData,models=c("GLM","GBM","CTA","RF","ANN","FDA"),models.options = Aarmata_opt,NbRunEval = 3,DataSplit = 70,VarImport = 3,do.full.models = F,modeling.id = "ex2")
Aarmata_models_NZ_Ire

# Step 7 Evaluation of Models
AarmataModelEval <- get_evaluations(Aarmata_models_NZ_Ire)
AarmataModelEval
AarmataModelEval["ROC","Testing.data",,,]
AarmataModelEval["TSS","Testing.data",,,]
get_variables_importance(Aarmata_models_NZ_Ire)
Aarmata_models_scores<-get_evaluations(Aarmata_models_NZ_Ire)

# Step 8 Projecting Models
Aramata_models_proj<- BIOMOD_Projection(modeling.output = Aarmata_models_NZ_Ire,new.env = Envi_Ire_sub, proj.name = 'current', selected.models = 'all', binary.meth = 'ROC', compress = 'xz', clamping.mask = F, output.format = '.grd')
plot(Aramata_models_proj,str.grep="GLM")
plot(Aramata_models_proj,str.grep="RF")
plot(Aramata_models_proj,str.grep="GBM")
plot(Aramata_models_proj,str.grep="CTA")
plot(Aramata_models_proj,str.grep="ANN")
plot(Aramata_models_proj,str.grep="FDA")

# Step 9 Ensemble Modeling
Aarmata_EM <- BIOMOD_EnsembleModeling(modeling.output = Aarmata_models_NZ_Ire,chosen.models = 'all',em.by='all',eval.metric = c('ROC'), eval.metric.quality.threshold = c(0.8), prob.mean = T,prob.median = T, prob.ci = T)

get_evaluations(Aarmata_EM)

# Step 10 Projecting of Ensemble Models
AarmataEF <- BIOMOD_EnsembleForecasting(EM.output = Aarmata_EM, projection.output = Aramata_models_proj)
AarmataEF
plot(AarmataEF)
AarmataModelEval["TSS","Testing.data",,,]
AarmataModelEval["ROC","Testing.data",,,]

# Step 11 Evaluation of Ensemble Models
get_evaluations(Aarmata_EM)

# This should be done another two times with new data provided in the SI. DataSpecies should be created with the two other csv files in Step 2 and all steps to be repeated with new occurrence data.
# This will create three sets of ensmeble models which then were merged together seperately from R studio.
