# Step 1
library(biomod2)
library(raster)
library(dismo)
library(sp)
library(sdmpredictors)
library(rgbif)
library(ade4)

# Step 2
setwd()
spp_Aspara<-name_suggest(q='Asparagopsis armata',rank = 'species',limit = 10000)
Armata_data_Ire<-occ_search(taxonKey = 5279840, country = 'IE', fields=c('name','key','country','decimalLatitude','decimalLongitude'),hasCoordinate = T,limit=1000,return = 'data')
View(Armata_data_Ire)
Armata_data_Ire[["data"]]
Armata_Ire<-(Armata_data_Ire[["data"]])
View(Armata_Ire)
write.csv(Armata_Ire,file = "~A.armata_Ireland.csv")
Armata_data_Ire<-read.csv("~A.armata_Ireland.csv", header=T)

# Step 3
Environment<-load_layers(c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m"))

# Step 4
Ireland<-shapefile('~/eez-2Ireland/eez.shp')
# Ireland eez shapefile provided in marineregions.org

# Step 5 
Envi_ire<-mask(Environment,Ireland)
Envi_ire<-crop(Environment,Ireland)
Envi_ire_sub<-stack(subset(Envi_ire,c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m"))) 

#Step 5a - If you wish to include biotic proxies, please use the following code instead of step 5. 
#Currently commented out
#ulva<-raster("proj_current_Ulva") #For ease, we have provided the projection layer of Ulva in the folder, but you would follow this code prior to analysis changing the species code
#ulva_ire<-mask(ulva, Ireland)
#ulva_ire<-crop(ulva, Ireland)
#Envi_ire_subi<-stack(subset(Envi_ire,c("BO_damean","BO_dissox","BO_nitrate","BO_ph","BO_phosphate","BO_sstrange","BO_sstmax","MS_biogeo08_sss_mean_5m", "MS_biogeo05_dist_shore_5m","MS_bathy_5m" ))) 
#Envi_ire_sub<-stack(c(Envi_ire_subi, ulva_ire))
                    
# Step 6 Environmental Variables Selection
#Armata_occ<-Ar_data[Ar_data_Ire$key=="Asparagopsis armata",]
Armata_occ<-Armata_data_Ire[Armata_data_Ire$key=="Asparagopsis armata",]
#Ar_cell_id<-cellFromXY(subset(Envi_ire,1),points_ar)
points_ar_ire<-data.frame(Armata_Ire[1:100,c("decimalLongitude","decimalLatitude")])
Envi_ire_df<-na.omit(as.data.frame(Envi_ire))
head(Envi_ire_df)
Ar_cell_id_Ire<-cellFromXY(subset(Envi_ire,1),points_ar_ire)
Envi_ire_df<-na.omit(as.data.frame(Envi_ire))
head(Envi_ire_df)
pca_ie<-dudi.pca(Envi_ire_df,scannf=F, nf=2)
plot(pca_ie$li[,1:2])
par(mfrow=c(1,2))
s.class(pca_ie$li[,1:2],fac = factor(rownames(Envi_ire_df)%in%Ar_cell_id_Ire,levels = c("FALSE","TRUE"),labels = c("B","A")),col=c("blue","red"),csta=0,cellipse = 3,cpoint = .3,pch = 10)
mtext("(a)",side=3,line = 3,adj = 0)
s.corcircle(pca_ie$co,clabel=.25)
mtext("(b)",side=3,line=3,adj=0)

#Step 7 Data formatting 
resp.name<-"Asparagopsis armata"
Aarmata_data_Ireland<-BIOMOD_FormatingData(resp.var = rep(1,nrow(Armata_Ire)),expl.var = Envi_ire_sub, resp.xy = Armata_Ire[,c('decimalLongitude','decimalLatitude')],resp.name=resp.name,PA.nb.rep=3,PA.nb.absences=10000,PA.strategy='random')
Aarmata_data_Ireland
plot(Aarmata_data_Ireland)

# Step 8 Modeling
Aarmata_opt<-BIOMOD_ModelingOptions()
Aarmata_models_Ire<-BIOMOD_Modeling(data=Aarmata_data_Ireland,models=c("GLM","GBM","CTA","RF","ANN","FDA"),models.options = Aarmata_opt,NbRunEval = 3,DataSplit = 70,VarImport = 3,do.full.models = F,modeling.id = "ex2")
Aarmata_models_Ire

# Step 9 Evaluation of Models
AarmataModelEval_Ire <- get_evaluations(Aarmata_models_Ire)
AarmataModelEval_Ire
AarmataModelEval_Ire["ROC","Testing.data",,,]
get_variables_importance(Aarmata_models_Ire)
Aarmata_models_scores_Ire<-get_evaluations(Aarmata_models_Ire)

# Step 10 Projecting Models
Aramata_models_proj<- BIOMOD_Projection(modeling.output = Aarmata_models_Ire,new.env = Envi_ire_sub, proj.name = 'current', selected.models = 'all', binary.meth = 'ROC', compress = 'xz', clamping.mask = F, output.format = '.grd')
plot(Aramata_models_proj,str.grep="GLM")
plot(Aramata_models_proj,str.grep="GBM")
plot(Aramata_models_proj,str.grep="CTA")
plot(Aramata_models_proj,str.grep="RF")
plot(Aramata_models_proj,str.grep="ANN")
plot(Aramata_models_proj,str.grep="FDA")

# Step 11 Ensemble Modeling
Aarmata_EM_Ire <- BIOMOD_EnsembleModeling(modeling.output = Aarmata_models_Ire,chosen.models = 'all',em.by='all',eval.metric = c('ROC'), eval.metric.quality.threshold = c(0.8), prob.mean = T,prob.median=T, prob.ci=T)

# Step 12 Projecting of Ensemble Models
AarmataEF_Ire <- BIOMOD_EnsembleForecasting(EM.output = Aarmata_EM_Ire, projection.output = Aramata_models_proj)
plot(AarmataEF_Ire)

# Step 13 Evaluation of Ensembel Models
get_evaluations(Aarmata_EM_Ire)

